#
# spec file for package genius
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           genius
Version:        1.0.27
Release:        1.13
Summary:        General purpose calculator and mathematics tool
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            http://www.jirka.org/genius.html
Source:         https://download.gnome.org/sources/genius/1.0/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  intltool
BuildRequires:  mpfr-devel >= 2.3.0
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.41.1
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.21.4
BuildRequires:  pkgconfig(gtksourceview-4) >= 3.99.7
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(pango) >= 1.22.0
BuildRequires:  pkgconfig(vte-2.91)
BuildRequires:  pkgconfig(x11)

%description
Genius is a general purpose calculator program similar in some aspects
to BC, Matlab, Maple or Mathematica. It is useful both as a simple
calculator and as a research or educational tool. The syntax
mimics how mathematics is usually written.

GEL (Genius Extenseion Language) is the name of its extension language.
Many of the standard genius functions are written in GEL itself.

%package -n gnome-genius
Summary:        GNOME interface for Genius, a general purpose calculator
Group:          Productivity/Scientific/Math
Requires:       %{name} = %{version}

%description -n gnome-genius
Genius is a general purpose calculator program similar in some aspects
to BC, Matlab, Maple or Mathematica. It is useful both as a simple
calculator and as a research or educational tool. The syntax mimics
how mathematics is usually written.

%package devel
Summary:        Development files for Genius, a general purpose calculator
Group:          Productivity/Scientific/Math
Requires:       %{name} = %{version}

%description devel
Genius is a general purpose calculator program similar in some aspects
to BC, Matlab, Maple or Mathematica. It is useful both as a simple
calculator and as a research or educational tool. The syntax
mimics how mathematics is usually written.

%lang_package

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -fstack-protector"
%configure \
	--libexec=%{_libexecdir}/genius \
	--disable-update-mimedb
%make_build

%install
%make_install
# We don't want the test plugin:
rm %{buildroot}%{_libdir}/genius/libtestplugin.*
rm %{buildroot}%{_datadir}/genius/plugins/test.plugin
# Not needed anymore on modern desktops:
rm %{buildroot}%{_datadir}/application-registry/genius.applications
rm %{buildroot}%{_datadir}/mime-info/genius.*
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}/genius

%files
%license COPYING
%doc NEWS README
%{_datadir}/genius
%{_bindir}/genius

%files -n gnome-genius
%{_bindir}/gnome-genius
%{_libexecdir}/genius
%{_datadir}/applications/gnome-genius.desktop
%{_datadir}/icons/hicolor/
%{_datadir}/mime/packages/genius.xml

%files devel
%doc AUTHORS ChangeLog TODO
%{_includedir}/genius

%files lang -f %{name}.lang

%changelog
* Thu Oct 28 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.27:
  + Add Save button to toolbar.
  + Add calculus example "zooming animation" to show
    differentiability.
  + Allow setting editor color scheme in the settings dialog.
  + Closing window acts exactly like the quit button/menu item.
  + Current program is marked with larger font instead of bold,
    since that doesn't work with all themes.
  + Improve performance of surface plots, and get rid of flicker.
  + Remove menu icons.
  + Leave the Stop button on the plot window enabled if a script is
    running.
  + Remove dependence on AMTK.
  + Updated translations.
- Drop pkgconfig(amtk-5) BuildRequires: following upstream changes.
* Fri Feb 19 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.0.26:
  + The range boxes in the plot dialog are now evalued rather than
    being spin boxes, so that one can use arbitrary genius
    expressions there.
  + Always spawn a new instance, none of this uniqueness nonsense.
  + Various fixes stemming from the port to GTK3 and from various
    new compiler warnings.
  + File chooser dialogs are now native.
  + Fix saving of settings in the presence of old style settings
    directories.
  + Set default gtksourceview colorscheme to "kate" as "classic" is
    hard to see in dark mode. It can be set in the config file (no
    GUI currently).
  + Updated translations.
* Fri Mar  6 2020 bjorn.lie@gmail.com
- Update to version 1.0.25:
  + Port to gtk-3.0.
  + Various bugfixes across the board.
- Replace ncurses-devel, pkgconfig(gtk+-2.0) and
  pkgconfig(gtksourceview-2.0) with pkgconfig(ncurses),
  pkgconfig(gtk+-3.0) and pkgconfig(gtksourceview-4) BuildRequires.
  Add pkgconfig(amtk-5) and pkgconfig(vte-2.91) BuildRequires: New
  dependencies.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Tue Jul  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Drop rarian-scrollkeeper-compat BuildRequires and stop passing
  - -disable-scrollkeeper to configure: No longer needed nor used or
  recognized.
- Drop translation-update-upstream BuildRequires and macro: genius
  is no longer in the t-u-u database, so no extra translations
  available.
- Update macros to current standard.
- Drop conditional hicolor-icon-theme, shared-mime-info and
  update-desktop-files BuildRequires and post(un) handling of
  relevant macros as well as gtk3-tools, update-desktop-files and
  shared-mime-info Requires(post(un)): No longer needed for any
  current supported version of openSUSE.
* Wed Jun 13 2018 luc14n0@linuxmail.org
- Add hicolor-icon-theme, update-desktop-files and shared-mime-info
  as BuildRequires and as Requires(post/postun) for right handling
  of post(un) scriptlets for suse_version < 1330.
* Mon Jun 11 2018 luc14n0@linuxmail.org
- Update to version 1.0.24:
  + Add: A RungeKutta and a plane curve plotting examples.
  + Updated translations.
- Drop:
  + BuildRoot tag: its standard value is already set by default.
  + update-desktop-files BuildRequires and suse_update_desktop_\
    file macro: they are no longer required.
  + pkgconfig(vte) BuildRequires: this is not required anymore now
    that Genius uses its own vte.
- Add gio-2.0, gio-unix-2.0, gobject-2.0, pango and x11 pkgconfig
  modules BuildRequires.
- Update:
  + '+' in GPL License tag to '-or-later' to comply with SPDX 3.0.
  + Post(un) scriptlets to be ran in release versions < 1330.
* Sat Sep  9 2017 jengelh@inai.de
- Ensure neutrality of description, remove rhetoric questions from
  description. Update package summaries.
* Thu Sep  7 2017 luc14n0@linuxmail.org
- Update to version 1.0.23:
  + Stop depending the build system on gnome-common.
  + Help is now built as HTML and displayed in the browser,meaning
    it actually works, links work, and it doesn't depend on any
    particular desktop environment being installed. The HTML help
    is also shown in the command line version when "manual" is run.
  + New example for Duffing equation.
  + New example on traces of the Peano function.
  + Couple of fixes/improvements in the examples.
  + Fix a crash on SurfacePlotDrawLines/Points.
  + Updated translations.
- Drop some %%dir and %%doc: no longer needed.
* Sat Jan 21 2017 zaitor@opensuse.org
- Replace scrollkeeper with rarian-scrollkeeper-compat
  BuildRequires: scollkeeper is dead, let's at least use the proper
  replacement.
* Mon Jan 16 2017 dimstar@opensuse.org
- Update to version 1.0.22:
  + Add a line plot version of the heat equation FDM animation.
    example, and improve the surface plot version.
  + Add argument principle example.
  + Add two Mandelbrot set examples and a Newton's fractal example.
  + Add examples for visualizing complex mappings.
  + Add example vizualizations for Riemann and Darboux sums.
  + Split the examples into submenus as there is now too many of
    them.
  + Add "filled" property to lines to allow drawing filled
    polygons.
  + Add LinePlotWaitForClick and LinePlotMouseLocation functions
    for interactive programs (used for some of the above new
    examples).
  + LinePlotDrawPoints and LinePlotDrawLine accept a column vector
    of complex nubmers.
  + Fix possible infinite loop on parse on systems with newer flex.
  + Fix setting of elements in transposed matrices (vectors).
  + Fix doc string to ErrorFunction.
  + Fix bad behavour upon double hitting "Run".
  + Fix vte deprecations, require 0.26 now.
  + Fix some strings and fixes to documentation.
  + Fix segfault when trying to swap a protected id with swapwith.
  + Fix StripZeroColumns behavior on a zero matrix.
  + Fix Subfactorial, and let Subfactorial, Factorial,
    DoubleFactorial apply over matrix.
  + Fix some inverse trig functions with complex arguments.
  + Other minor fixes including some crashes.
* Tue Jan 12 2016 dimstar@opensuse.org
- Update to version 1.0.21:
  + Add vibrating drumhead modes example, heat equation with
    explicit FDM, improve the Laplace FDM example.
  + Fix output of chopped floating point numbers, especially
    chopped imaginary parts.
  + Fix output of results as floats in pretty print.
  + Fix SurfacePlotVariableNames to redraw when changing variable
    names.
  + Updated translations.
* Thu Mar 12 2015 dimstar@opensuse.org
- Update to version 1.0.20:
  + Add more sizes of icons including SVG, and add Keywords to the
    .desktop file.
  + Documentation updates.
  + Fix PeriodicExtension function.
  + ErrorFunction (erf) is using MPFR for real values so it is far
    more precise and faster.
  + The Fourier series example is no longer using a hand coded
    graph and hand computed series, so it can now be easily
    modified to show series for different functions.
  + Fix GCC 5 compilation.
  + A couple of minor fixes in the plotting code including one
    possible crasher.
  + Updated translations.
* Wed Sep 24 2014 dimstar@opensuse.org
- Update to version 1.0.19:
  + New menu: Examples. These are annotated programs that show some
    mathematical concept. Generally taken from the classes I have
    been teaching. They are installed under
    prefix/share/genius/examples/ and are mostly using graphics so
    only work in the graphical GNOME/GTK version
  + New plotting functions: SurfacePlotDrawLine,
    SurfacePlotDrawPoints, SurfacePlotClear, PlotWindowPresent.
  + New rotation animation in the surface plot window.
  + Fix string constants from compiled library starting with 'E'.
  + A few fixes.
  + Updated translations.
* Sat Sep 13 2014 zaitor@opensuse.org
- Update to version 1.0.18:
  + New general functions: KroneckerProduct (alias TensorProduct),
    NewtonsMethod, HalleysMethod, LambertW, LambertWm1,
    NonzeroColumns, NonzeroElements, DisplayVariables, PrintTable,
    SetElement, SetVElement.
  + New plotting functions: PlotCanvasFreeze/PlotCanvasThaw to
    improve flicker if doing animations with genius, and
    LinePlotDrawPoints function to draw just points without the
    line. While plotting errors are no longer forced into a dialog,
    and presence of errors is indicated in the graph window below
    the graph.
  + Allow setting color in LinePlotDrawLine with RGB vector. When
    the vector building notation is done with floats and the final
    number is within 2^-20 times the step size of the goal, assume
    there were roundoff errors and still add it, just like for
    loops, so something like 1.0:0.1:3.0 now works.
  + Implement subsecond precision in wait function.
  + Fix memory corruption error triggered in nested floating point
    for loops with a floating point step.
  + Few minor bug fixes and fix some more compile warnings in
    gtkextra.
  + Streamline the compiled file format (saves about 30kb).
  + A few improvements to the documentation.
  + Updated translations.
* Thu Jun 27 2013 zaitor@opensuse.org
- Update to version 1.0.17:
  + Better precision for graphs especially when zoomed it a lot,
    and make font smaller if needed.
  + Line plots and parametric plots now allow "fit dependent axis"
    automatically when y limits are unspecified. And this is the
    default in the UI.
  + Add export of graphs to PDF directly.
  + Line plot step size is adaptive, also line plots now detect
    jumps and do not draw a connecting line, try plotting UnitStep
    for example.
  + Use arrow keys to move around a line plot.
  + left-right arrow keys rotate surface plot.
  + All plots are now antialiased on the screen (due to GtkExtra
    update and cairo usage).
  + Update internal GtkExtra to 3.0.5, and forward port all our
    changes/fixes (this gets us closer to supporting GTK+3 at some
    point).
  + Completion for "help on function" in the GUI.
  + Fix FindRootBisection and FindRootMullersMethod.
  + Factors is now a lot faster on very large numbers (as fast as
    Factorize).
  + Fix placement of labels on surface plots.
  + A few small fixes and updates to the documentation.
  + A few minor bugfixes.
  + Update mersenne primes (new one is known).
  + Updated translations.
* Mon Dec 17 2012 dimstar@opensuse.org
- Update to version 1.0.16:
  + Add SurfacePlotData and SurfacePlotDataGrid functions to draw
    arbitrary surface data, to allow more complicated 3d plots and
    3d plots from data.
  + Add LinePlotDrawAxisLabels and SurfacePlotDrawLegends
    parameters and add corresponding UI checkboxes
  + Add ExportPlot function to export the current contents of the
    plot window to a file from GEL
  + Surface plot now allows "fit dependent axis" automatically when
    z limits are unspecified.  And this is the default in the UI
  + Add sinc, BesselJ0, BesselJ1, BesselJn, BesselY0, BesselY1,
    BesselYn functions
  + Plot window slightly bigger (700x500 now) and there are wider
    side margins in the lineplot (2D) version to make tick labels
    always fit.
  + In both 2D and 3D plots, tick labels now use scientific
    notation when needed to avoid ugly labels
  + In surface plot the gradient always shows only the range of the
    function, so color is more useful when zoomed out.
  + Simpler output when typing "help foo" when foo is neither
    defined nor documented.
  + When for/sum/prod loops are in terms of floating point numbers
    and the final number is within 2^-20 times the step size of the
    goal, assume there were roundoff errors and still execute the
    body
  + Handle wider matrices than 2^15 columns in expansion
  + Fix flicker when plotting surfaces to allow animations with 3d
    plots
  + Fix possible uninitialized crash when reading badly formed
    standard library (should never happen, but ...)
  + Fix LinearRecursiveSequence and allow it to take vector for n
  + Fix crash on uninitialized variables in conjugate transpose
  + Fix crash on extreme zoom out or zoom in of a graph
  + Fix derivatives of Im and Re
  + Fix file chooser dialogs not starting in current directory
  + Avoid double error about uninitialized variables
  + Spelling fixes and documentation fixes
  + Require MPFR at least 2.3.0
  + Updated translations.
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 1.0.15:
  + New functions CurrentTime, MacaulayRep, MacaulayLowerOperator,
    MacaulayBound.
  + Fix rational powers of negative numbers, and exact negative
    rational powers.
  + Fix zooming in graphs using the mouse when the functions take
    long to run.
  + Accept log instead of ln for symbolic derivative when used with
    only one parameter.
  + Updated translations.
* Mon Oct  3 2011 vuntz@opensuse.org
- Add explicit shared-mime-info BuildRequires since we use the
  %%mime_database_* macros.
* Sun Jul 31 2011 vuntz@opensuse.org
- Update to version 1.0.14:
  + Fix some compilation warnings
  + Fix a crasher
  + Optimize and quantize the new pngs for a smaller file
  + Updated translations.
- Drop genius-fix-warnings.patch: fixed upstream.
* Fri Jul 29 2011 vuntz@opensuse.org
- Update to version 1.0.13:
  + Add ShuffleVector
  + Add increment and swapwith operators
  + Require gtk 2.18 and fix up some deprecated function usage
  + Slightly more cache friendly matrix traversal
  + Optimize Combinations, Permutations, SortVector,
    IntegerQuotient
  + Lots of tiny random optimizations
  + Open help even if the URI api is broken
  + Make pngs in the distribution smaller yet
  + Make the compiled library slightly smaller
  + Some more vector functions accept null properly
  + Minor portability fixes
  + Updated translations.
- Add gnome-doc-utils-devel BuildRequires for new dependency.
- Add genius-fix-warnings.patch: fix build warnings that make the
  build fail.
* Thu Apr 28 2011 vuntz@opensuse.org
- Move to pkgconfig()-style BuildRequires:
  + Old ones: gtk2-devel, gtksourceview-devel, vte-devel.
  + New ones: glib-2.0, gtk+-2.0, gtksourceview-2.0, vte.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
  + %%mime_database_post/postun because the package ships a mime
    type definition.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
- Remove shared-mime-info Requires: if it's not there, then we
  simply don't need to update the mime database.
* Thu Nov 25 2010 dimstar@opensuse.org
- Update to version 1.0.12:
  + Recently used files menu
  + Only run ps2epsi on eps output if selected, it can be very slow
    and I've realized it's not commonly needed
  + Fix handling of comment at the end of file when running from
    the IDE
  + Fix handling of newlines in the lexer
  + Fix CrossProduct
  + Some self tests were missing in the distro
  + Fix 64 bit build to be warning free
  + Fix buld on Make 3.82
  + Updated translations
- Drop genius-make382.patch: fixed upstream. As a consequence, also
  remove the autoreconf call in build.
* Sat Sep 11 2010 dimstar@opensuse.org
- Add genius-make382.patch: Fix build with make 3.82
- Add autoreconf call in build section.
* Fri Sep 10 2010 dimstar@opensuse.org
- Update to version 1.0.11:
  + Build fix for some versions of ncurses
  + Minor documentation updates.
* Thu Sep  9 2010 dimstar@opensuse.org
- Update to version 1.0.10:
  + Allow changing variable names for all plotting functions
  + Add SlopefieldTicks, VectorfieldTicks, LinePlotVariableNames,
    and SurfacePlotVariableNames, parameters
  + Add AskButtons interactive function
  + CHANGE: spelling fix: AuxiliaryUnitMatrix doesn't have two l's
  + Support for setting legend on LinePlotDrawLine with a "legend"
    parameter
  + Allow comparisons (== and !=) with null, treating it as an
    empty matrix
  + Uses GIO instead of GnomeVFS
  + Fix compilation without gtksourceview
  + Fix some crashes in plotting code
  + Allow slopefield solutions to leave plot window by a small
    fudge factor.
  + Fix zooming plots so that we can zoom by moving mouse in any
    direction
  + Fix compilation with newer sealed vte
  + Fix up some typos in the documentation
  + Updated translations.
- Drop genius-sealed-vte.patch, fixed upstream.
- Remove gnome-vfs2-devel BuildRequires.
* Mon Aug 30 2010 vuntz@opensuse.org
- Add genius-sealed-vte.patch to fix build with latest vte, which
  seals the vte API.
* Wed May 12 2010 dimstar@opensuse.org
- PreRequire shared-mime-info
- Do not package .omf files twice.
* Fri Dec 25 2009 vuntz@opensuse.org
- Update to version 1.0.9:
  + Fix matrix expansion. This also fixes AuxilliaryUnitMatrix and
    JordanBlock.
  + Fix several possible crashers.
  + Fix a minor memory leak.
* Fri Nov 13 2009 vuntz@opensuse.org
- Update to version 1.0.8:
  + Buildfixes for Cygwin and parallel builds
  + Check events before executing a command line, fixes a race
    which results in display anomalies on new vte.
  + Documentation updates
  + Require GTK/GLib 2.12 and use the new tooltips API.
* Fri Jul 31 2009 vuntz@novell.com
- Update to version 1.0.7:
  + SYNTAX: Added a possibility to exactly specify which variables
    are copied into a function's extra dictionary when it is being
    returned. E.g. "`(x) [x0] = (x-x0)" will copy x0 from the
    current context. This is a lot more efficient than the current
    behaviour which tries to copy everything referenced.
  + SYNTAX: Add "local" variables by specifying "local x,y,z" or
    "local *" as the first statement in a function. Local
    variables are not visible from higher contexts (functions
    called within)
  + CHANGE: all system parameters are now protected and cannot be
    redefined using the "parameter" keyword
  + Add UserVariables, UndefineAll, ProtectAll, and add Undefine as
    an alias to undefine.
  + Add trigonometric Fourier series related functions:
    NumericalFourierSeriesFunction,
    NumericalFourierSineSeriesFunction,
    NumericalFourierCosineSeriesFunction, FourierSeriesFunction,
    NumericalFourierSeriesCoefficients,
    NumericalFourierSineSeriesCoefficients,
    NumericalFourierCosineSeriesCoefficients, PeriodicExtension,
    EvenPeriodicExtension, OddPeriodicExtension
  + Fix changing floating point precision!
  + Fix uninitialized variable in graphing
  + Improve variable substitution for returned functions to be more
    efficient. Slightly changes behaviour with respect to global
    functions and variables used.
  + Plot windows now not treated annoyingly as dialogs
  + Fix compilation/decompilation of all function attributes.
  + Parse/Evaluate with a syntax error at end of string no longer
    terminate genius
  + Updated Mersenne stuff for the newest data from mersenne.org
    and fix MersennePrimeExponents
  + Fix opening new files from the command line.
  + Update the gel library to use the new language features.
  + Various other minor fixes
  + Translation updates.
* Sun Jun 14 2009 vuntz@novell.com
- Clean package for Contrib.
